import disnake

class Paginator(disnake.ui.View):
    def __init__(self, message: disnake.Message, embeds: list):
        self.message = message
        self.embeds = embeds
        self.page = 0

        super().__init__(timeout=30)

    @disnake.ui.button(style=disnake.ButtonStyle.primary, emoji='⬅️')
    async def button_left(self, button: disnake.ui.Button, interaction: disnake.Interaction):
        if self.page == 0:
            self.page = len(self.embeds) - 1
        else:
            self.page -= 1

        await self.button_callback(interaction)

    @disnake.ui.button(style=disnake.ButtonStyle.primary, emoji='➡️')
    async def button_right(self, button: disnake.ui.Button, interaction: disnake.Interaction):
        if self.page == len(self.embeds) - 1:
            self.page = 0
        else:
            self.page += 1

        await self.button_callback(interaction)

    async def start(self):
        await self.message.edit(embed=self.embeds[self.page], view=Paginator(self.message, self.embeds))

    async def button_callback(self, interaction: disnake.Interaction):
        await interaction.response.edit_message(embed=self.embeds[self.page])


import setuptools

requirements = ["disnake>=2.1.2"]

setuptools.setup(
	# Имя дистрибутива пакета. Оно должно быть уникальным, поэтому добавление вашего имени пользователя в конце является обычным делом.
	name="CoffeePaginator",
	# Номер версии вашего пакета. Обычно используется семантическое управление версиями.
	version="1.0a",
	# Имя автора.
	author="Sha4ek",
	# Краткое описание, которое будет показано на странице PyPi.
	description="Простой модуль для создания страниц в Disnake",
	# URL-адрес, представляющий домашнюю страницу проекта. Большинство проектов ссылаются на репозиторий.
	url="https://github.com/Sha4ek/CoffeePaginator",
	# Находит все пакеты внутри проекта и объединяет их в дистрибутив.
	packages=setuptools.find_packages(),
	# Предоставляет pip некоторые метаданные о пакете. Также отображается на странице PyPi.
	install_requires=requirements,

	classifiers=[
		"Programming Language :: Python :: 3.8",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	# Требуемая версия Python.
	python_requires='>=3.8',
)